@@ -11,9 +11,14 @@ from sprox.iprovider import IProvider
 from sprox.util import timestamp
 import datetime, inspect
 
-from ming.orm import mapper, ForeignIdProperty, FieldProperty, RelationProperty
-from ming.orm.declarative import MappedClass
-from ming.orm.property import OneToManyJoin, ManyToOneJoin, ORMProperty
+try:
+    from ming.odm import mapper, ForeignIdProperty, FieldProperty, RelationProperty
+    from ming.odm.declarative import MappedClass
+    from ming.odm.property import OneToManyJoin, ManyToOneJoin, ORMProperty
+except ImportError: #pragma nocover
+    from ming.orm import mapper, ForeignIdProperty, FieldProperty, RelationProperty
+    from ming.orm.declarative import MappedClass
+    from ming.orm.property import OneToManyJoin, ManyToOneJoin, ORMProperty
 from ming import schema as S
 import bson
 from bson import ObjectId
@@ -201,7 +206,10 @@ class MingProvider(IProvider):
         field = getattr(field, 'field', None)
         if field is not None:
             if field.type is S.DateTime or field.type is datetime.datetime:
-                return datetime.datetime.strptime(value, "%Y-%m-%d %H:%M:%S")
+                if isinstance(value, basestring):
+                    return datetime.datetime.strptime(value, "%Y-%m-%d %H:%M:%S")
+                else:
+                    return value
             elif field.type is S.Binary:
                 return bson.Binary(value)
             elif field.type in (S.Int, int):
