@@ -22,7 +22,10 @@ Released under MIT license.
 
 from sprox.validatorselector import ValidatorSelector
 from ming import schema as s
-import ming.orm as o
+try:
+    import ming.odm as o
+except ImportError: #pragma: no cover
+    import ming.orm as o
 import inspect
 
 from formencode.validators import StringBool, Number, UnicodeString as FEUnicodeString, Email, Int
@@ -34,7 +37,6 @@ try: #pragma: no cover
 except ImportError: #pragma: no cover
     from tw.forms.validators import *
     DateTimeValidator = DateValidator
-    UnicodeString = FEUnicodeString
 
 class MingValidatorSelector(ValidatorSelector):
 
