@@ -191,8 +191,12 @@ class ViewBase(ConfigBase):
 
         for field_name in self.__hide_fields__:
             if field_name not in self.__omit_fields__:
-                field = self.__metadata__[field_name]
-                args = self._do_get_field_widget_args(field_name, field)
+                args = {}
+                try:
+                    field = self.__metadata__[field_name]
+                    args = self._do_get_field_widget_args(field_name, field)
+                except KeyError: #pragma: no cover
+                    pass
                 if field_name in self.__field_widget_args__:
                     args.update(self.__field_widget_args__[field_name])
                 fields[field_name] = HiddenField(**args)
