@@ -4,6 +4,7 @@ from sprox.test.base import widget_children, widget_is_type, form_error_message
 from sprox.test.mg.base import setup_database, sorted_user_columns, SproxTest, setup_records, Example, Document, assert_in_xml
 from sprox.metadata import FieldsMetadata
 from nose.tools import raises, eq_
+from nose import SkipTest
 from formencode.validators import FieldsMatch, NotEmpty, OpenId
 from sprox.widgetselector import WidgetSelector, EntityDefWidget, EntityDefWidgetSelector, RecordFieldWidget, RecordViewWidgetSelector
 from sprox.mg.provider import MingProvider
@@ -19,9 +20,11 @@ from bson.objectid import InvalidId
 
 from ming import schema as S
 from ming.orm import FieldProperty
+from pymongo.errors import ConnectionFailure
 
 from sprox.widgets import *
 from formencode import Invalid
+from datetime import datetime
 
 class MyTextField(TextField):pass
 
@@ -32,7 +35,10 @@ user = None
 def setup():
     global session, engine, metadata, user
     session, engine, metadata = setup_database()
-    user = setup_records(session)
+    try:
+        user = setup_records(session)
+    except ConnectionFailure:
+        raise SkipTest('MongoDB not running...')
 
 class UserForm(FormBase):
     __entity__ = User
@@ -661,6 +667,19 @@ class TestMGORMProvider(SproxTest):
         eq_(new_user.email_address, u'asdf@asdf.commy')
         eq_(q_user.email_address, u'asdf@asdf.commy')
 
+    def test_update_datetime(self):
+        params = {'user_name':u'asdf2', 'password':u'asdf2', 'email_address':u'email@addy.com'}
+        new_user = self.provider.create(User, params)
+        params['email_address'] = u'asdf@asdf.commy'
+        params['created'] = datetime.utcnow().replace(microsecond=0)
+        params['_id'] = new_user._id
+        session.flush()
+        new_user = self.provider.update(User, params)
+        q_user = User.query.find({ "_id": new_user._id }).first()
+        eq_(new_user.email_address, u'asdf@asdf.commy')
+        eq_(q_user.email_address, u'asdf@asdf.commy')
+        eq_(q_user.created, params['created'])
+
     def test_update_sprox_id(self):
         params = {'user_name':u'asdf2', 'password':u'asdf2', 'email_address':u'email@addy.com', 'sprox_id': 'xyz'}
         new_user = self.provider.create(User, params)
